@@ -13,4 +13,4 @@ export DBUS_SESSION_BUS_ADDRESS
 export XAUTHORITY=/dev/null
 
 # change to the directory where your autopilot tests live, and run them
-HAS_CCPANEL=0 LANG=C DEJA_DUP_TESTING=1 PYTHONDONTWRITEBYTECODE=1 PYTHONPATH=. ../../tests/shell autopilot run deja_dup_autopilot.test_overwrite.OverwriteTests.test_overwrite_one
+LANG=C DEJA_DUP_TESTING=1 PYTHONDONTWRITEBYTECODE=1 PYTHONPATH=. ../../tests/shell autopilot run deja_dup_autopilot.test_overwrite.OverwriteTests.test_overwrite_one
